@@ -82,9 +82,6 @@ volatile gboolean is_available;
 
 extern AgsApplicationContext *ags_application_context;
 
-AgsGuiThread *gui_thread;
-AgsTaskThread *task_thread;
-
 void
 ags_functional_mixer_test_add_test()
 {
@@ -114,13 +111,6 @@ ags_functional_mixer_test_add_test()
 int
 ags_functional_mixer_test_init_suite()
 {
-  /* get gui thread */
-  gui_thread = ags_thread_find_type(ags_application_context->main_loop,
-				    AGS_TYPE_GUI_THREAD);
-
-  task_thread = ags_thread_find_type(ags_application_context->main_loop,
-				     AGS_TYPE_TASK_THREAD);
-    
   return(0);
 }
 
@@ -163,7 +153,7 @@ ags_functional_mixer_test_resize_pads()
   /* retrieve mixer */
   nth_machine = 0;
 
-  list_start = gtk_container_get_children(xorg_application_context->window->machines);
+  list_start = gtk_container_get_children(AGS_WINDOW(xorg_application_context->window)->machines);
   list = g_list_nth(list_start,
 		    nth_machine);
 
@@ -244,7 +234,7 @@ ags_functional_mixer_test_resize_audio_channels()
   /* retrieve mixer */
   nth_machine = 0;
 
-  list_start = gtk_container_get_children(xorg_application_context->window->machines);
+  list_start = gtk_container_get_children(AGS_WINDOW(xorg_application_context->window)->machines);
   list = g_list_nth(list_start,
 		    nth_machine);
 
@@ -317,8 +307,7 @@ main(int argc, char **argv)
   ags_functional_test_util_do_run(argc, argv,
 				  ags_functional_mixer_test_add_test, &is_available);
 
-  pthread_join(ags_functional_test_util_self(),
-	       NULL);
+  g_thread_join(ags_functional_test_util_test_runner_thread());
 
   return(-1);
 }
